@@ -5,16 +5,17 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
+
+from ansible.errors import AnsibleActionFail
 from ansible.playbook.task import Task
 from ansible.template import Templar
-from ansible.errors import AnsibleActionFail
 
-from ansible_collections.ansible.utils.plugins.action.validate import (
-    ActionModule,
-)
+from ansible_collections.ansible.utils.plugins.action.validate import ActionModule
+
 
 try:
     from unittest.mock import MagicMock  # pylint:disable=syntax-error
@@ -61,21 +62,15 @@ CRITERIA_CRC_ERROR_CHECK = {
         "^.*": {
             "type": "object",
             "properties": {
-                "counters": {
-                    "properties": {
-                        "in_crc_errors": {"type": "number", "maximum": 0}
-                    }
-                }
+                "counters": {"properties": {"in_crc_errors": {"type": "number", "maximum": 0}}},
             },
-        }
+        },
     },
 }
 
 CRITERIA_ENABLED_CHECK = {
     "type": "object",
-    "patternProperties": {
-        "^.*": {"type": "object", "properties": {"enabled": {"enum": [True]}}}
-    },
+    "patternProperties": {"^.*": {"type": "object", "properties": {"enabled": {"enum": [True]}}}},
 }
 
 CRITERIA_OPER_STATUS_UP_CHECK = {
@@ -84,7 +79,7 @@ CRITERIA_OPER_STATUS_UP_CHECK = {
         "^.*": {
             "type": "object",
             "properties": {"oper_status": {"type": "string", "pattern": "up"}},
-        }
+        },
     },
 }
 
@@ -96,15 +91,11 @@ CRITERIA_IN_RATE_CHECK = {
             "properties": {
                 "counters": {
                     "properties": {
-                        "rate": {
-                            "properties": {
-                                "in_rate": {"type": "number", "maximum": 0}
-                            }
-                        }
-                    }
-                }
+                        "rate": {"properties": {"in_rate": {"type": "number", "maximum": 0}}},
+                    },
+                },
             },
-        }
+        },
     },
 }
 
@@ -120,7 +111,7 @@ CRITERIA_FORMAT_SUPPORT_CHECK = {
 }
 
 
-class TestValidate(unittest.TestCase):
+class TestValidate(TestCase):
     def setUp(self):
         task = MagicMock(Task)
         play_context = MagicMock()
@@ -182,9 +173,7 @@ class TestValidate(unittest.TestCase):
 
         with self.assertRaises(AnsibleActionFail) as error:
             self._plugin.run(task_vars=None)
-        self.assertIn(
-            "'criteria' option value is invalid", str(error.exception)
-        )
+        self.assertIn("'criteria' option value is invalid", str(error.exception))
 
     def test_invalid_validate_plugin_config_options(self):
         """Check passing invalid validate plugin options"""
@@ -195,11 +184,9 @@ class TestValidate(unittest.TestCase):
             "criteria": CRITERIA_IN_RATE_CHECK,
         }
 
-        result = self._plugin.run(
-            task_vars={"ansible_validate_jsonschema_draft": "draft0"}
-        )
+        result = self._plugin.run(task_vars={"ansible_validate_jsonschema_draft": "draft0"})
         self.assertIn(
-            "value of draft must be one of: draft3, draft4, draft6, draft7, got: draft0",
+            "value of draft must be one of: draft3, draft4, draft6, draft7, 2019-09, 2020-12, got: draft0",
             result["msg"],
         )
 
@@ -212,9 +199,7 @@ class TestValidate(unittest.TestCase):
             "criteria": CRITERIA_IN_RATE_CHECK,
         }
 
-        result = self._plugin.run(
-            task_vars={"ansible_validate_jsonschema_draft": "draft3"}
-        )
+        result = self._plugin.run(task_vars={"ansible_validate_jsonschema_draft": "draft3"})
         self.assertIn("All checks passed", result["msg"])
 
     def test_validate_plugin_config_options_with_draft4(self):
@@ -226,9 +211,7 @@ class TestValidate(unittest.TestCase):
             "criteria": CRITERIA_IN_RATE_CHECK,
         }
 
-        result = self._plugin.run(
-            task_vars={"ansible_validate_jsonschema_draft": "draft4"}
-        )
+        result = self._plugin.run(task_vars={"ansible_validate_jsonschema_draft": "draft4"})
         self.assertIn("All checks passed", result["msg"])
 
     def test_validate_plugin_config_options_with_draft6(self):
@@ -240,9 +223,7 @@ class TestValidate(unittest.TestCase):
             "criteria": CRITERIA_IN_RATE_CHECK,
         }
 
-        result = self._plugin.run(
-            task_vars={"ansible_validate_jsonschema_draft": "draft6"}
-        )
+        result = self._plugin.run(task_vars={"ansible_validate_jsonschema_draft": "draft6"})
         self.assertIn("All checks passed", result["msg"])
 
     def test_invalid_data(self):
@@ -263,9 +244,7 @@ class TestValidate(unittest.TestCase):
             "patternProperties.^.*.properties.counters.properties.in_crc_errors.maximum",
             result["msg"],
         )
-        self.assertIn(
-            "patternProperties.^.*.properties.enabled.enum", result["msg"]
-        )
+        self.assertIn("patternProperties.^.*.properties.enabled.enum", result["msg"])
         self.assertIn(
             "'patternProperties.^.*.properties.oper_status.pattern",
             result["msg"],
@@ -306,3 +285,15 @@ class TestValidate(unittest.TestCase):
 
         result = self._plugin.run(task_vars=None)
         self.assertIn("Validation errors were found", result["msg"])
+
+    def test_support_for_disabled_format_with_invalid_data(self):
+        """Check passing valid data as per criteria"""
+
+        self._plugin._task.args = {
+            "engine": "ansible.utils.jsonschema",
+            "data": IN_VALID_DATA,
+            "criteria": CRITERIA_FORMAT_SUPPORT_CHECK,
+        }
+
+        result = self._plugin.run(task_vars=dict(ansible_validate_jsonschema_check_format=False))
+        self.assertIn("All checks passed", result["msg"])
