@@ -23,12 +23,16 @@ options:
     name:
         description:
             - Only show results for a specific app service plan.
+        type: str
     resource_group:
         description:
             - Limit results by resource group.
+        type: str
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -38,20 +42,20 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Get facts for app service plan by name
-      azure_rm_appserviceplan_info:
-        resource_group: myResourceGroup
-        name: myAppServicePlan
+- name: Get facts for app service plan by name
+  azure_rm_appserviceplan_info:
+    resource_group: myResourceGroup
+    name: myAppServicePlan
 
-    - name: Get azure_rm_appserviceplan_facts for app service plan in resource group
-      azure_rm_appserviceplan_info:
-        resource_group: myResourceGroup
+- name: Get azure_rm_appserviceplan_facts for app service plan in resource group
+  azure_rm_appserviceplan_info:
+    resource_group: myResourceGroup
 
-    - name: Get facts for app service plan with tags
-      azure_rm_appserviceplan_info:
-        tags:
-          - testtag
-          - foo:bar
+- name: Get facts for app service plan with tags
+  azure_rm_appserviceplan_info:
+    tags:
+      - testtag
+      - foo:bar
 '''
 
 RETURN = '''
@@ -115,8 +119,7 @@ appserviceplans:
                     sample: 1
 '''
 try:
-    from msrestazure.azure_exceptions import CloudError
-    from azure.common import AzureMissingResourceHttpError, AzureHttpError
+    from azure.core.exceptions import ResourceNotFoundError
 except Exception:
     # This is handled in azure_rm_common
     pass
@@ -133,7 +136,7 @@ class AzureRMAppServicePlanInfo(AzureRMModuleBase):
         self.module_arg_spec = dict(
             name=dict(type='str'),
             resource_group=dict(type='str'),
-            tags=dict(type='list')
+            tags=dict(type='list', elements='str')
         )
 
         self.results = dict(changed=False)
@@ -150,10 +153,6 @@ class AzureRMAppServicePlanInfo(AzureRMModuleBase):
 
     def exec_module(self, **kwargs):
 
-        is_old_facts = self.module._name == 'azure_rm_appserviceplan_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_appserviceplan_facts' module has been renamed to 'azure_rm_appserviceplan_info'", version=(2.9, ))
-
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
 
@@ -172,8 +171,8 @@ class AzureRMAppServicePlanInfo(AzureRMModuleBase):
         result = []
 
         try:
-            item = self.web_client.app_service_plans.get(self.resource_group, self.name)
-        except CloudError:
+            item = self.web_client.app_service_plans.get(resource_group_name=self.resource_group, name=self.name)
+        except ResourceNotFoundError:
             pass
 
         if item and self.has_tags(item.tags, self.tags):
@@ -185,8 +184,8 @@ class AzureRMAppServicePlanInfo(AzureRMModuleBase):
     def list_by_resource_group(self):
         self.log('List app service plans in resource groups {0}'.format(self.resource_group))
         try:
-            response = list(self.web_client.app_service_plans.list_by_resource_group(self.resource_group))
-        except CloudError as exc:
+            response = list(self.web_client.app_service_plans.list_by_resource_group(resource_group_name=self.resource_group))
+        except Exception as exc:
             self.fail("Error listing app service plan in resource groups {0} - {1}".format(self.resource_group, str(exc)))
 
         results = []
@@ -200,7 +199,7 @@ class AzureRMAppServicePlanInfo(AzureRMModuleBase):
         self.log('List app service plans in current subscription')
         try:
             response = list(self.web_client.app_service_plans.list())
-        except CloudError as exc:
+        except Exception as exc:
             self.fail("Error listing app service plans: {0}".format(str(exc)))
 
         results = []
@@ -216,14 +215,14 @@ class AzureRMAppServicePlanInfo(AzureRMModuleBase):
         curated_output = dict()
         curated_output['id'] = plan_facts['id']
         curated_output['name'] = plan_facts['name']
-        curated_output['resource_group'] = plan_facts['properties']['resourceGroup']
+        curated_output['resource_group'] = plan_facts['resource_group']
         curated_output['location'] = plan_facts['location']
         curated_output['tags'] = plan_facts.get('tags', None)
         curated_output['is_linux'] = False
         curated_output['kind'] = plan_facts['kind']
         curated_output['sku'] = plan_facts['sku']
 
-        if plan_facts['properties'].get('reserved', None):
+        if plan_facts.get('reserved', None):
             curated_output['is_linux'] = True
 
         return curated_output
