@@ -1,19 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: path_trace
 short_description: Resource module for Path Trace
 description:
-- Manage operations create and delete of the resource Path Trace.
-- >
-   Initiates a new flow analysis with periodic refresh and stat collection options. Returns a request id and a task
-   id to get results and follow progress.
-- Deletes a flow analysis request by its id.
+  - This module represents an alias of the module path_trace_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -26,7 +20,7 @@ options:
     description: Destination IP address.
     type: str
   destPort:
-    description: Destination Port.
+    description: Destination Port, range 1-65535.
     type: str
   flowAnalysisId:
     description: FlowAnalysisId path parameter. Flow analysis request id.
@@ -40,35 +34,29 @@ options:
     description: Periodic refresh of path for every 30 sec.
     type: bool
   protocol:
-    description: Protocol.
+    description: Protocol - one of TCP, UDP - checks both when left blank.
     type: str
   sourceIP:
     description: Source IP address.
     type: str
   sourcePort:
-    description: Source Port.
+    description: Source Port, range 1-65535.
     type: str
 requirements:
-- dnacentersdk >= 2.6.0
-- python >= 3.9
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Path Trace InitiateANewPathtrace
-  description: Complete reference of the InitiateANewPathtrace API.
-  link: https://developer.cisco.com/docs/dna-center/#!initiate-a-new-pathtrace
-- name: Cisco DNA Center documentation for Path Trace DeletesPathtraceById
-  description: Complete reference of the DeletesPathtraceById API.
-  link: https://developer.cisco.com/docs/dna-center/#!deletes-pathtrace-by-id
+  - name: Cisco DNA Center documentation for Path Trace InitiateANewPathtraceV1
+    description: Complete reference of the InitiateANewPathtraceV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!initiate-a-new-pathtrace
+  - name: Cisco DNA Center documentation for Path Trace DeletesPathtraceByIdV1
+    description: Complete reference of the DeletesPathtraceByIdV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!deletes-pathtrace-by-id
 notes:
-  - SDK Method used are
-    path_trace.PathTrace.deletes_pathtrace_by_id,
-    path_trace.PathTrace.initiate_a_new_pathtrace,
-
-  - Paths used are
-    post /dna/intent/api/v1/flow-analysis,
-    delete /dna/intent/api/v1/flow-analysis/{flowAnalysisId},
-
+  - SDK Method used are path_trace.PathTrace.deletes_pathtrace_by_id_v1, path_trace.PathTrace.initiate_a_new_pathtrace_v1,
+  - Paths used are post /dna/intent/api/v1/flow-analysis, delete /dna/intent/api/v1/flow-analysis/{flowAnalysisId},
+  - It should be noted that this module is an alias of path_trace_v1
 """
-
 EXAMPLES = r"""
 - name: Create
   cisco.dnac.path_trace:
@@ -84,12 +72,11 @@ EXAMPLES = r"""
     destIP: string
     destPort: string
     inclusions:
-    - string
+      - string
     periodicRefresh: true
     protocol: string
     sourceIP: string
     sourcePort: string
-
 - name: Delete by id
   cisco.dnac.path_trace:
     dnac_host: "{{dnac_host}}"
@@ -101,9 +88,7 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     state: absent
     flowAnalysisId: string
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
