@@ -7,11 +7,10 @@ from __future__ import absolute_import, division, print_function
 
 
 __metaclass__ = type
-
 from textwrap import dedent
+from unittest.mock import patch
 
 from ansible_collections.cisco.ios.plugins.modules import ios_bgp_address_family
-from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
 from ansible_collections.cisco.ios.tests.unit.modules.utils import set_module_args
 
 from .ios_module import TestIosModule
@@ -23,33 +22,12 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
     def setUp(self):
         super(TestIosBgpAddressFamilyModule, self).setUp()
 
-        self.mock_get_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config",
-        )
-        self.get_config = self.mock_get_config.start()
-
-        self.mock_load_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config",
-        )
-        self.load_config = self.mock_load_config.start()
-
-        self.mock_get_resource_connection_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base."
-            "get_resource_connection",
-        )
-        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
-
         self.mock_get_resource_connection_facts = patch(
             "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base."
             "get_resource_connection",
         )
         self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
 
-        self.mock_edit_config = patch(
-            "ansible_collections.cisco.ios.plugins.module_utils.network.ios.providers.providers.CliProvider.edit_config",
-        )
-        self.edit_config = self.mock_edit_config.start()
-
         self.mock_execute_show_command = patch(
             "ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.bgp_address_family.bgp_address_family."
             "Bgp_address_familyFacts.get_bgp_address_family_data",
@@ -58,11 +36,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
 
     def tearDown(self):
         super(TestIosBgpAddressFamilyModule, self).tearDown()
-        self.mock_get_resource_connection_config.stop()
         self.mock_get_resource_connection_facts.stop()
-        self.mock_edit_config.stop()
-        self.mock_get_config.stop()
-        self.mock_load_config.stop()
         self.mock_execute_show_command.stop()
 
     def test_ios_bgp_address_family_merged(self):
@@ -143,9 +117,13 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                             neighbors=[
                                 dict(
                                     neighbor_address="198.51.100.1",
-                                    remote_as=65100,
-                                    route_maps=[dict(name="test-route-out", out="true")],
-                                    prefix_lists=[dict(name="AS65100-PREFIX-OUT", out="true")],
+                                    remote_as="65.11",
+                                    route_maps=[
+                                        dict(name="test-route-out", out="true"),
+                                    ],
+                                    prefix_lists=[
+                                        dict(name="AS65100-PREFIX-OUT", out="true"),
+                                    ],
                                 ),
                             ],
                         ),
@@ -153,7 +131,9 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                             afi="nsap",
                             bgp=dict(aggregate_timer=20, dmzlink_bw=True, scan_time=10),
                             default_metric=10,
-                            networks=[dict(address="192.0.1.1", route_map="test_route")],
+                            networks=[
+                                dict(address="192.0.1.1", route_map="test_route"),
+                            ],
                         ),
                     ],
                 ),
@@ -169,7 +149,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "bgp aggregate-timer 20",
             "bgp dmzlink-bw",
             "bgp scan-time 10",
-            "neighbor 198.51.100.1 remote-as 65100",
+            "neighbor 198.51.100.1 remote-as 65.11",
             "neighbor 198.51.100.1 route-map test-route-out out",
             "network 192.0.1.1 route-map test_route",
             "default-metric 10",
@@ -231,6 +211,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               neighbor TEST-PEER-GROUP send-community
               neighbor TEST-PEER-GROUP next-hop-self all
               neighbor 2001:db8::1 activate
+              maximum-secondary-paths eibgp 2
+              maximum-paths 12
              !
              address-family ipv4 multicast
               table-map test_tableMap filter
@@ -253,7 +235,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               network 198.51.110.10 mask 255.255.255.255 backdoor
               aggregate-address 192.0.2.1 255.255.255.255 as-confed-set
               neighbor 198.51.100.1 remote-as 10
-              neighbor 198.51.100.1 local-as 20
+              neighbor 198.51.100.1 local-as 10.64760
               neighbor 198.51.100.1 activate
               neighbor 198.51.100.1 next-hop-self all
               neighbor 198.51.100.1 aigp send cost-community 100 poi igp-cost transitive
@@ -271,6 +253,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                         {
                             "afi": "ipv4",
                             "bgp": {"redistribute_internal": True},
+                            "maximum_paths": {"paths": 12},
+                            "maximum_secondary_paths": {"eibgp": 2},
                             "neighbors": [
                                 {
                                     "neighbor_address": "TEST-PEER-GROUP",
@@ -342,18 +326,25 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                         "send": {
                                             "cost_community": {
                                                 "id": 100,
-                                                "poi": {"igp_cost": True, "transitive": True},
+                                                "poi": {
+                                                    "igp_cost": True,
+                                                    "transitive": True,
+                                                },
                                             },
                                         },
                                     },
-                                    "local_as": {"number": 20, "set": True},
+                                    "local_as": {"number": "10.64760", "set": True},
                                     "neighbor_address": "198.51.100.1",
                                     "nexthop_self": {"all": True},
-                                    "prefix_lists": [{"name": "AS65100-PREFIX-OUT", "out": True}],
+                                    "prefix_lists": [
+                                        {"name": "AS65100-PREFIX-OUT", "out": True},
+                                    ],
                                     "remote_as": 10,
                                     "route_maps": [{"name": "test-out", "out": True}],
                                     "route_server_client": True,
-                                    "slow_peer_options": {"detection": {"threshold": 150}},
+                                    "slow_peer_options": {
+                                        "detection": {"threshold": 150},
+                                    },
                                 },
                             ],
                             "networks": [
@@ -451,7 +442,9 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                     address="198.51.110.1",
                                     activate=True,
                                     remote_as=200,
-                                    route_maps=[dict(name="test-replaced-route", out=True)],
+                                    route_maps=[
+                                        dict(name="test-replaced-route", out=True),
+                                    ],
                                 ),
                             ],
                         ),
@@ -559,12 +552,17 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                         send=dict(
                                             cost_community=dict(
                                                 id=100,
-                                                poi=dict(igp_cost=True, transitive=True),
+                                                poi=dict(
+                                                    igp_cost=True,
+                                                    transitive=True,
+                                                ),
                                             ),
                                         ),
                                     ),
                                     nexthop_self=dict(all=True),
-                                    prefix_lists=[dict(name="AS65100-PREFIX-OUT", out="true")],
+                                    prefix_lists=[
+                                        dict(name="AS65100-PREFIX-OUT", out="true"),
+                                    ],
                                     slow_peer=[dict(detection=dict(threshold=150))],
                                     remote_as=10,
                                     local_as=dict(number=20),
@@ -681,14 +679,17 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                             afi="ipv4",
                             bgp=dict(redistribute_internal=True),
                             redistribute=[
+                                dict(connected=dict(set=True)),
                                 dict(
-                                    connected=dict(set=True),
                                     ospf=dict(
+                                        process_id=200,
+                                        metric=100,
                                         match=dict(
-                                            external=True,
                                             internal=True,
-                                            type_1=True,
-                                            type_2=True,
+                                            externals=dict(
+                                                type_1=True,
+                                                type_2=True,
+                                            ),
                                         ),
                                     ),
                                 ),
@@ -731,12 +732,17 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                         send=dict(
                                             cost_community=dict(
                                                 id=100,
-                                                poi=dict(igp_cost=True, transitive=True),
+                                                poi=dict(
+                                                    igp_cost=True,
+                                                    transitive=True,
+                                                ),
                                             ),
                                         ),
                                     ),
                                     nexthop_self=dict(all=True),
-                                    prefix_lists=[dict(name="AS65100-PREFIX-OUT", out="true")],
+                                    prefix_lists=[
+                                        dict(name="AS65100-PREFIX-OUT", out="true"),
+                                    ],
                                     slow_peer=[dict(detection=dict(threshold=150))],
                                     remote_as=10,
                                     local_as=dict(number=20),
@@ -792,6 +798,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                 state="overridden",
             ),
         )
+
         self.execute_module(changed=False, commands=[])
 
     def test_ios_bgp_address_family_deleted(self):
@@ -935,6 +942,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                             afi="ipv4",
                             safi="multicast",
                             vrf="blue",
+                            maximum_paths=dict(paths=12),
+                            maximum_secondary_paths=dict(eibgp=2),
                             aggregate_address=[
                                 dict(
                                     address="192.0.2.1",
@@ -958,7 +967,10 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                         send=dict(
                                             cost_community=dict(
                                                 id=100,
-                                                poi=dict(igp_cost=True, transitive=True),
+                                                poi=dict(
+                                                    igp_cost=True,
+                                                    transitive=True,
+                                                ),
                                             ),
                                         ),
                                     ),
@@ -1017,6 +1029,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "router bgp 65000",
             "address-family ipv4 multicast vrf blue",
             "bgp dampening 1 1 1 1",
+            "maximum-secondary-paths eibgp 2",
+            "maximum-paths 12",
             "neighbor 198.51.100.1 remote-as 10",
             "neighbor 198.51.100.1 activate",
             "neighbor 198.51.100.1 aigp send cost-community 100 poi igp-cost transitive",
@@ -1055,6 +1069,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                       neighbor TEST-PEER-GROUP send-community
                       neighbor TEST-PEER-GROUP next-hop-self all
                       neighbor 2001:db8::1 activate
+                      maximum-secondary-paths eibgp 2
+                      maximum-paths 12
                      !
                      address-family ipv4 multicast
                       table-map test_tableMap filter
@@ -1098,7 +1114,24 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                 {
                     "afi": "ipv4",
                     "bgp": {"redistribute_internal": True},
-                    "redistribute": [{"connected": {"set": True}}],
+                    "redistribute": [
+                        {"connected": {"set": True}},
+                        {
+                            "ospf": {
+                                "process_id": 200,
+                                "metric": 100,
+                                "match": {
+                                    "internal": True,
+                                    "externals": {
+                                        "type_1": True,
+                                        "type_2": True,
+                                    },
+                                },
+                            },
+                        },
+                    ],
+                    "maximum_paths": {"paths": 12},
+                    "maximum_secondary_paths": {"eibgp": 2},
                     "neighbors": [
                         {
                             "send_community": {"set": True},
@@ -1158,7 +1191,11 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                         },
                     },
                     "networks": [
-                        {"address": "198.51.110.10", "mask": "255.255.255.255", "backdoor": True},
+                        {
+                            "address": "198.51.110.10",
+                            "mask": "255.255.255.255",
+                            "backdoor": True,
+                        },
                     ],
                     "aggregate_addresses": [
                         {
@@ -1169,8 +1206,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                     ],
                     "neighbors": [
                         {
-                            "remote_as": 10,
-                            "local_as": {"set": True, "number": 20},
+                            "remote_as": "10",
+                            "local_as": {"set": True, "number": "20"},
                             "activate": True,
                             "neighbor_address": "198.51.100.1",
                             "nexthop_self": {"all": True},
@@ -1183,7 +1220,9 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                 },
                             },
                             "route_server_client": True,
-                            "prefix_lists": [{"name": "AS65100-PREFIX-OUT", "out": True}],
+                            "prefix_lists": [
+                                {"name": "AS65100-PREFIX-OUT", "out": True},
+                            ],
                             "slow_peer_options": {"detection": {"threshold": 150}},
                             "route_maps": [{"name": "test-out", "out": True}],
                         },
@@ -1323,6 +1362,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "address-family ipv4 multicast",
             "no default-metric 12",
             "no distance bgp 10 10 100",
+            "no redistribute ospf 200",
             "no table-map test_tableMap filter",
             "no network 198.51.111.11 mask 255.255.255.255 route-map test",
             "no aggregate-address 192.0.3.1 255.255.255.255 as-confed-set",
