@@ -7,11 +7,10 @@ from __future__ import absolute_import, division, print_function
 
 
 __metaclass__ = type
-
 from textwrap import dedent
+from unittest.mock import patch
 
 from ansible_collections.cisco.ios.plugins.modules import ios_interfaces
-from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
 from ansible_collections.cisco.ios.tests.unit.modules.utils import set_module_args
 
 from .ios_module import TestIosModule
@@ -23,33 +22,12 @@ class TestIosInterfacesModule(TestIosModule):
     def setUp(self):
         super(TestIosInterfacesModule, self).setUp()
 
-        self.mock_get_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config",
-        )
-        self.get_config = self.mock_get_config.start()
-
-        self.mock_load_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config",
-        )
-        self.load_config = self.mock_load_config.start()
-
-        self.mock_get_resource_connection_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base."
-            "get_resource_connection",
-        )
-        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
-
         self.mock_get_resource_connection_facts = patch(
             "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base."
             "get_resource_connection",
         )
         self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
 
-        self.mock_edit_config = patch(
-            "ansible_collections.cisco.ios.plugins.module_utils.network.ios.providers.providers.CliProvider.edit_config",
-        )
-        self.edit_config = self.mock_edit_config.start()
-
         self.mock_execute_show_command = patch(
             "ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.interfaces.interfaces."
             "InterfacesFacts.get_interfaces_data",
@@ -58,11 +36,7 @@ class TestIosInterfacesModule(TestIosModule):
 
     def tearDown(self):
         super(TestIosInterfacesModule, self).tearDown()
-        self.mock_get_resource_connection_config.stop()
         self.mock_get_resource_connection_facts.stop()
-        self.mock_edit_config.stop()
-        self.mock_get_config.stop()
-        self.mock_load_config.stop()
         self.mock_execute_show_command.stop()
 
     def test_ios_interfaces_merged(self):
@@ -79,6 +53,7 @@ class TestIosInterfacesModule(TestIosModule):
              speed 1000
              mtu 1500
              no negotiation auto
+             source template ANSIBLE
             interface GigabitEthernet3
              description Ansible UT interface 3
              no ip address
@@ -91,6 +66,7 @@ class TestIosInterfacesModule(TestIosModule):
              no ip address
              shutdown
              negotiation auto
+             source template ANSIBLE
             interface GigabitEthernet5
              description Ansible UT interface 5
              no ip address
@@ -99,6 +75,7 @@ class TestIosInterfacesModule(TestIosModule):
              ipv6 dhcp server
             interface GigabitEthernet6
              description Ansible UT interface 6
+             source template NOCHANGE
             """,
         )
         set_module_args(
@@ -108,11 +85,13 @@ class TestIosInterfacesModule(TestIosModule):
                         "description": "This interface should be disabled",
                         "enabled": True,
                         "name": "GigabitEthernet1",
+                        "template": "ANSIBLE",
                     },
                     {
                         "description": "This interface should be enabled",
                         "enabled": False,
                         "name": "GigabitEthernet0/1",
+                        "template": "DISABLED",
                     },
                     {"mode": "layer3", "name": "GigabitEthernet6"},
                 ],
@@ -122,9 +101,11 @@ class TestIosInterfacesModule(TestIosModule):
         commands = [
             "interface GigabitEthernet0/1",
             "description This interface should be enabled",
+            "source template DISABLED",
             "shutdown",
             "interface GigabitEthernet1",
             "description This interface should be disabled",
+            "source template ANSIBLE",
             "interface GigabitEthernet6",
             "no switchport",
         ]
@@ -168,7 +149,10 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
+                    {
+                        "description": "Ansible UT interface 1",
+                        "name": "GigabitEthernet1",
+                    },
                     {
                         "description": "Ansible UT interface 2",
                         "name": "GigabitEthernet0/1",
@@ -189,6 +173,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
+             source template ANSIBLE
             interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
@@ -221,23 +206,30 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
+                    {
+                        "description": "Ansible UT interface 1",
+                        "name": "GigabitEthernet1",
+                    },
                     {"name": "GigabitEthernet0/1", "speed": 1200, "mtu": 1800},
                     {
                         "name": "GigabitEthernet6",
                         "description": "Ansible UT interface 6",
                         "mode": "layer2",
+                        "template": "ANSIBLE",
                     },
                 ],
                 "state": "replaced",
             },
         )
         commands = [
+            "interface GigabitEthernet1",
+            "no source template ANSIBLE",
             "interface GigabitEthernet0/1",
             "no description Ansible UT interface 2",
             "speed 1200",
             "mtu 1800",
             "interface GigabitEthernet6",
+            "source template ANSIBLE",
             "switchport",
         ]
         result = self.execute_module(changed=True)
@@ -280,7 +272,10 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
+                    {
+                        "description": "Ansible UT interface 1",
+                        "name": "GigabitEthernet1",
+                    },
                     {
                         "description": "Ansible UT interface 2",
                         "name": "GigabitEthernet0/1",
@@ -328,6 +323,7 @@ class TestIosInterfacesModule(TestIosModule):
             interface GigabitEthernet6
              description Ansible UT interface 6
              no switchport
+             source template ANSIBLE_INTERFACE_6
             """,
         )
         set_module_args(
@@ -363,6 +359,7 @@ class TestIosInterfacesModule(TestIosModule):
             "shutdown",
             "interface GigabitEthernet6",
             "no description Ansible UT interface 6",
+            "no source template ANSIBLE_INTERFACE_6",
             "shutdown",
             "switchport",
             "interface GigabitEthernet1",
@@ -386,6 +383,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
+             source template ANSIBLE
             interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
@@ -416,6 +414,7 @@ class TestIosInterfacesModule(TestIosModule):
         commands = [
             "interface GigabitEthernet1",
             "no description Ansible UT interface 1",
+            "no source template ANSIBLE",
             "shutdown",
         ]
         result = self.execute_module(changed=True)
@@ -564,6 +563,7 @@ class TestIosInterfacesModule(TestIosModule):
                     interface GigabitEthernet7
                      description Ansible UT interface 7
                      no switchport
+                     source template ANSIBLE
                     """,
                 ),
                 state="parsed",
@@ -578,14 +578,22 @@ class TestIosInterfacesModule(TestIosModule):
                 "mtu": 1500,
                 "enabled": True,
             },
-            {"name": "GigabitEthernet1", "description": "Ansible UT interface 1", "enabled": True},
+            {
+                "name": "GigabitEthernet1",
+                "description": "Ansible UT interface 1",
+                "enabled": True,
+            },
             {
                 "name": "GigabitEthernet3",
                 "description": "Ansible UT interface 3",
                 "enabled": False,
                 "duplex": "auto",
             },
-            {"name": "GigabitEthernet4", "description": "Ansible UT interface 4", "enabled": False},
+            {
+                "name": "GigabitEthernet4",
+                "description": "Ansible UT interface 4",
+                "enabled": False,
+            },
             {
                 "name": "GigabitEthernet5",
                 "description": "Ansible UT interface 5",
@@ -603,6 +611,7 @@ class TestIosInterfacesModule(TestIosModule):
                 "mode": "layer3",
                 "description": "Ansible UT interface 7",
                 "enabled": True,
+                "template": "ANSIBLE",
             },
         ]
         self.assertEqual(parsed_list, result["parsed"])
@@ -610,17 +619,6 @@ class TestIosInterfacesModule(TestIosModule):
     def test_ios_interfaces_rendered(self):
         self.execute_show_command.return_value = dedent(
             """\
-            interface GigabitEthernet1
-             description Ansible UT interface 1
-            interface GigabitEthernet0/1
-             description Ansible UT interface 2
-             ip address dhcp
-            interface GigabitEthernet3
-             no ip address
-            interface GigabitEthernet4
-             negotiation auto
-            interface GigabitEthernet5
-             ipv6 dhcp server
             """,
         )
         set_module_args(
@@ -639,7 +637,7 @@ class TestIosInterfacesModule(TestIosModule):
                         "enabled": True,
                     },
                     {
-                        "name": "GigabitEthernet3",
+                        "name": "gigabitEthernet3",
                         "description": "Ansible UT interface 3",
                         "enabled": True,
                         "duplex": "auto",
@@ -654,6 +652,67 @@ class TestIosInterfacesModule(TestIosModule):
                         "description": "Ansible UT interface 5",
                         "duplex": "full",
                         "enabled": True,
+                        "template": "ANSIBLE",
+                    },
+                    {
+                        "name": "twentyFiveGigE1",
+                        "description": "Ansible UT TwentyFiveGigE",
+                    },
+                    {
+                        "name": "twoGigabitEthernet2",
+                        "description": "Ansible UT TwoGigabitEthernet",
+                    },
+                    {
+                        "name": "tenGigabitEthernet1",
+                        "description": "Ansible UT TenGigabitEthernet",
+                    },
+                    {
+                        "name": "fastEthernet1",
+                        "description": "Ansible UT FastEthernet",
+                    },
+                    {
+                        "name": "fortyGigabitEthernet1",
+                        "description": "Ansible UT FortyGigabitEthernet",
+                    },
+                    {
+                        "name": "fiveGigabitEthernet",
+                        "description": "Ansible UT FiveGigabitEthernet",
+                    },
+                    {
+                        "name": "fiftyGigabitEthernet",
+                        "description": "Ansible UT for fiftyGigabitEthernet",
+                    },
+                    {
+                        "name": "FoUrHuNdReDgIgE",
+                        "description": "Ansible UT for FourHundredGigE",
+                    },
+                    {
+                        "name": "ethernet1",
+                        "description": "Ansible UT Ethernet",
+                    },
+                    {
+                        "name": "vlan10",
+                        "description": "Ansible UT Vlan",
+                    },
+                    {
+                        "name": "loopback999",
+                        "description": "Ansible UT loopback",
+                    },
+                    {
+                        "name": "port-channel01",
+                        "description": "Ansible UT port-channel",
+                    },
+                    {
+                        "name": "nve1",
+                        "description": "Ansible UT nve",
+                    },
+                    {
+                        "name": "hundredGigE1",
+                        "description": "Ansible UT HundredGigE",
+                    },
+                    {
+                        "name": "serial0/1",
+                        "description": "Ansible UT Serial",
                     },
                 ],
                 state="rendered",
@@ -679,6 +738,52 @@ class TestIosInterfacesModule(TestIosModule):
             "interface GigabitEthernet5",
             "description Ansible UT interface 5",
             "duplex full",
+            "source template ANSIBLE",
+            "no shutdown",
+            "interface TwentyFiveGigE1",
+            "description Ansible UT TwentyFiveGigE",
+            "no shutdown",
+            "interface TwoGigabitEthernet2",
+            "description Ansible UT TwoGigabitEthernet",
+            "no shutdown",
+            "interface TenGigabitEthernet1",
+            "description Ansible UT TenGigabitEthernet",
+            "no shutdown",
+            "interface FastEthernet1",
+            "description Ansible UT FastEthernet",
+            "no shutdown",
+            "interface FortyGigabitEthernet1",
+            "description Ansible UT FortyGigabitEthernet",
+            "no shutdown",
+            "interface FiveGigabitEthernet",
+            "description Ansible UT FiveGigabitEthernet",
+            "no shutdown",
+            "interface FiftyGigabitEthernet",
+            "description Ansible UT for fiftyGigabitEthernet",
+            "no shutdown",
+            "interface FourHundredGigE",
+            "description Ansible UT for FourHundredGigE",
+            "no shutdown",
+            "interface Ethernet1",
+            "description Ansible UT Ethernet",
+            "no shutdown",
+            "interface Vlan10",
+            "description Ansible UT Vlan",
+            "no shutdown",
+            "interface loopback999",
+            "description Ansible UT loopback",
+            "no shutdown",
+            "interface Port-channel01",
+            "description Ansible UT port-channel",
+            "no shutdown",
+            "interface nve1",
+            "description Ansible UT nve",
+            "no shutdown",
+            "interface HundredGigE1",
+            "description Ansible UT HundredGigE",
+            "no shutdown",
+            "interface Serial0/1",
+            "description Ansible UT Serial",
             "no shutdown",
         ]
         result = self.execute_module(changed=False)
