@@ -5,14 +5,13 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: guest_location_info
 short_description: Information module for Guest Location
 description:
-- Get all Guest Location.
-- Get Guest Location by id.
-- This API allows the client to get a guest location by ID.
-- This API allows the client to get all the guest locations.
+  - Get all Guest Location.
+  - Get Guest Location by id.
+  - This API allows the client to get a guest location by ID.
+  - This API allows the client to get all the guest locations.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -20,62 +19,59 @@ author: Rafael Campos (@racampos)
 options:
   id:
     description:
-    - Id path parameter.
+      - Id path parameter.
     type: str
   page:
     description:
-    - Page query parameter. Page number.
+      - Page query parameter. Page number.
     type: int
   size:
     description:
-    - Size query parameter. Number of objects returned per page.
+      - Size query parameter. Number of objects returned per page.
     type: int
   sortasc:
     description:
-    - Sortasc query parameter. Sort asc.
+      - Sortasc query parameter. Sort asc.
     type: str
   sortdsc:
     description:
-    - Sortdsc query parameter. Sort desc.
+      - Sortdsc query parameter. Sort desc.
     type: str
   filter:
     description:
-    - >
-      Filter query parameter. **Simple filtering** should be available through the filter query string parameter.
-      The structure of a filter is a triplet of field operator and value separated with dots. More than one filter
-      can be sent. The logical operator common to ALL filter criteria will be by default AND, and can be changed
-      by using the "filterType=or" query string parameter.
-    - Each resource Data model description should specify if an attribute is a filtered field.
-    - The 'EQ' operator describes 'Equals'.
-    - The 'NEQ' operator describes 'Not Equals'.
-    - The 'GT' operator describes 'Greater Than'.
-    - The 'LT' operator describes 'Less Than'.
-    - The 'STARTSW' operator describes 'Starts With'.
-    - The 'NSTARTSW' operator describes 'Not Starts With'.
-    - The 'ENDSW' operator describes 'Ends With'.
-    - The 'NENDSW' operator describes 'Not Ends With'.
-    - The 'CONTAINS' operator describes 'Contains'.
-    - The 'NCONTAINS' operator describes 'Not Contains'.
+      - >
+        Filter query parameter. **Simple filtering** should be available through the filter query string parameter. The structure of a filter
+        is a triplet of field operator and value separated with dots. More than one filter can be sent. The logical operator common to ALL filter
+        criteria will be by default AND, and can be changed by using the "filterType=or" query string parameter.
+      - Each resource Data model description should specify if an attribute is a filtered field.
+      - The 'EQ' operator describes 'Equals'.
+      - The 'NEQ' operator describes 'Not Equals'.
+      - The 'GT' operator describes 'Greater Than'.
+      - The 'LT' operator describes 'Less Than'.
+      - The 'STARTSW' operator describes 'Starts With'.
+      - The 'NSTARTSW' operator describes 'Not Starts With'.
+      - The 'ENDSW' operator describes 'Ends With'.
+      - The 'NENDSW' operator describes 'Not Ends With'.
+      - The 'CONTAINS' operator describes 'Contains'.
+      - The 'NCONTAINS' operator describes 'Not Contains'.
     elements: str
     type: list
   filterType:
     description:
-    - >
-      FilterType query parameter. The logical operator common to ALL filter criteria will be by default AND, and
-      can be changed by using the parameter.
+      - >
+        FilterType query parameter. The logical operator common to ALL filter criteria will be by default AND, and can be changed by using the
+        parameter.
     type: str
 requirements:
-- ciscoisesdk >= 2.2.1
-- python >= 3.5
+  - ciscoisesdk >= 2.2.3
+  - python >= 3.5
 notes:
   - SDK Method used are
     guest_location.GuestLocation.get_guest_location_by_id,
     guest_location.GuestLocation.get_guest_location_generator,
-
   - Paths used are
     get /ers/config/guestlocation,
     get /ers/config/guestlocation/{id},
-
 """
 
 EXAMPLES = r"""
@@ -92,7 +88,6 @@ EXAMPLES = r"""
     filter: []
     filterType: AND
   register: result
-
 - name: Get Guest Location by id
   cisco.ise.guest_location_info:
     ise_hostname: "{{ise_hostname}}"
@@ -101,7 +96,6 @@ EXAMPLES = r"""
     ise_verify: "{{ise_verify}}"
     id: string
   register: result
-
 """
 
 RETURN = r"""
@@ -119,7 +113,6 @@ ise_response:
         "type": "string"
       }
     }
-
 ise_responses:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
