@@ -5,40 +5,39 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: mnt_authentication_status_info
-short_description: Information module for Mnt Authentication Status
+short_description: Information module for MNT Authentication Status
 description:
-- Get all Mnt Authentication Status.
-version_added: '1.1.0'
+  - Get all MNT Authentication Status.
+version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options:
   MAC:
     description:
-    - MAC path parameter.
+      - MAC path parameter.
     type: str
   SECONDS:
     description:
-    - SECONDS path parameter.
+      - SECONDS path parameter.
     type: str
   RECORDS:
     description:
-    - RECORDS path parameter.
+      - RECORDS path parameter.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
-- python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Mnt Authentication Status reference
-  description: Complete reference of the Mnt Authentication Status object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+  - ciscoisesdk >= 2.2.3
+  - python >= 3.5
+notes:
+  - SDK Method used are
+    misc.Misc.get_authentication_status_by_mac,
+  - Paths used are
+    get /AuthStatus/MACAddress/{MAC}/{SECONDS}/{RECORDS}/All,
 """
 
 EXAMPLES = r"""
-- name: Get all Mnt Authentication Status
+- name: Get all MNT Authentication Status
   cisco.ise.mnt_authentication_status_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -48,7 +47,6 @@ EXAMPLES = r"""
     SECONDS: string
     RECORDS: string
   register: result
-
 """
 
 RETURN = r"""
@@ -56,6 +54,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
