@@ -5,14 +5,13 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: telemetry_info
 short_description: Information module for Telemetry Info
 description:
-- Get all Telemetry Info.
-- Get Telemetry Info by id.
-- This API allows the client to get all the telemetry information.
-- This API allows the client to get telemetry information by ID.
+  - Get all Telemetry Info.
+  - Get Telemetry Info by id.
+  - This API allows the client to get all the telemetry information.
+  - This API allows the client to get telemetry information by ID.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -20,58 +19,55 @@ author: Rafael Campos (@racampos)
 options:
   id:
     description:
-    - Id path parameter.
+      - Id path parameter.
     type: str
   page:
     description:
-    - Page query parameter. Page number.
+      - Page query parameter. Page number.
     type: int
   size:
     description:
-    - Size query parameter. Number of objects returned per page.
+      - Size query parameter. Number of objects returned per page.
     type: int
   filter:
     description:
-    - >
-      Filter query parameter. **Simple filtering** should be available through the filter query string parameter.
-      The structure of a filter is a triplet of field operator and value separated with dots. More than one filter
-      can be sent. The logical operator common to ALL filter criteria will be by default AND, and can be changed
-      by using the "filterType=or" query string parameter.
-    - Each resource Data model description should specify if an attribute is a filtered field.
-    - The 'EQ' operator describes 'Equals'.
-    - The 'NEQ' operator describes 'Not Equals'.
-    - The 'GT' operator describes 'Greater Than'.
-    - The 'LT' operator describes 'Less Than'.
-    - The 'STARTSW' operator describes 'Starts With'.
-    - The 'NSTARTSW' operator describes 'Not Starts With'.
-    - The 'ENDSW' operator describes 'Ends With'.
-    - The 'NENDSW' operator describes 'Not Ends With'.
-    - The 'CONTAINS' operator describes 'Contains'.
-    - The 'NCONTAINS' operator describes 'Not Contains'.
+      - >
+        Filter query parameter. **Simple filtering** should be available through the filter query string parameter. The structure of a filter
+        is a triplet of field operator and value separated with dots. More than one filter can be sent. The logical operator common to ALL filter
+        criteria will be by default AND, and can be changed by using the "filterType=or" query string parameter.
+      - Each resource Data model description should specify if an attribute is a filtered field.
+      - The 'EQ' operator describes 'Equals'.
+      - The 'NEQ' operator describes 'Not Equals'.
+      - The 'GT' operator describes 'Greater Than'.
+      - The 'LT' operator describes 'Less Than'.
+      - The 'STARTSW' operator describes 'Starts With'.
+      - The 'NSTARTSW' operator describes 'Not Starts With'.
+      - The 'ENDSW' operator describes 'Ends With'.
+      - The 'NENDSW' operator describes 'Not Ends With'.
+      - The 'CONTAINS' operator describes 'Contains'.
+      - The 'NCONTAINS' operator describes 'Not Contains'.
     elements: str
     type: list
   filterType:
     description:
-    - >
-      FilterType query parameter. The logical operator common to ALL filter criteria will be by default AND, and
-      can be changed by using the parameter.
+      - >
+        FilterType query parameter. The logical operator common to ALL filter criteria will be by default AND, and can be changed by using the
+        parameter.
     type: str
 requirements:
-- ciscoisesdk >= 2.2.1
-- python >= 3.5
+  - ciscoisesdk >= 2.2.3
+  - python >= 3.5
 seealso:
-- name: Cisco ISE documentation for TelemetryInformation
-  description: Complete reference of the TelemetryInformation API.
-  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!telemetryinfo
+  - name: Cisco ISE documentation for TelemetryInformation
+    description: Complete reference of the TelemetryInformation API.
+    link: https://developer.cisco.com/docs/identity-services-engine/v1/#!telemetryinfo
 notes:
   - SDK Method used are
     telemetry_information.TelemetryInformation.get_telemetry_info_by_id,
     telemetry_information.TelemetryInformation.get_telemetry_information_generator,
-
   - Paths used are
     get /ers/config/telemetryinfo,
     get /ers/config/telemetryinfo/{id},
-
 """
 
 EXAMPLES = r"""
@@ -86,7 +82,6 @@ EXAMPLES = r"""
     filter: []
     filterType: AND
   register: result
-
 - name: Get Telemetry Info by id
   cisco.ise.telemetry_info:
     ise_hostname: "{{ise_hostname}}"
@@ -95,7 +90,6 @@ EXAMPLES = r"""
     ise_verify: "{{ise_verify}}"
     id: string
   register: result
-
 """
 
 RETURN = r"""
@@ -115,7 +109,6 @@ ise_response:
         "type": "string"
       }
     }
-
 ise_responses:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
