@@ -18,13 +18,14 @@
 # along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
 
 import copy
-import pytest
 import random
 import string
 from unittest.mock import MagicMock
 from unittest.mock import call
 from unittest.mock import patch
 
+import pytest
+
 try:
     import botocore
 except ImportError:
@@ -32,13 +33,13 @@ except ImportError:
     pass
 
 from ansible.errors import AnsibleError
+
 from ansible_collections.amazon.aws.plugins.module_utils.botocore import HAS_BOTO3
-from ansible_collections.community.aws.plugins.inventory.aws_mq import (
-    InventoryModule,
-    _find_hosts_matching_statuses,
-    _get_broker_host_tags,
-    _add_details_to_hosts,
-)
+
+from ansible_collections.community.aws.plugins.inventory.aws_mq import InventoryModule
+from ansible_collections.community.aws.plugins.inventory.aws_mq import _add_details_to_hosts
+from ansible_collections.community.aws.plugins.inventory.aws_mq import _find_hosts_matching_statuses
+from ansible_collections.community.aws.plugins.inventory.aws_mq import _get_broker_host_tags
 
 if not HAS_BOTO3:
     pytestmark = pytest.mark.skip("test_aws_mq.py requires the python modules 'boto3' and 'botocore'")
@@ -54,8 +55,8 @@ def make_clienterror_exception(code="AccessDenied"):
     )
 
 
-@pytest.fixture()
-def inventory():
+@pytest.fixture(name="inventory")
+def fixture_inventory():
     inventory = InventoryModule()
     inventory.inventory = MagicMock()
     inventory.inventory.set_variable = MagicMock()
@@ -75,8 +76,8 @@ def inventory():
     return inventory
 
 
-@pytest.fixture()
-def connection():
+@pytest.fixture(name="connection")
+def fixture_connection():
     conn = MagicMock()
     return conn
 
@@ -535,13 +536,13 @@ def test_inventory_add_hosts(m_get_mq_hostname, inventory, hostvars_prefix, host
         tmp = []
         for host in camel_hosts:
             new_host = copy.deepcopy(host)
-            for key in host:
+            for key, value in host.items():
                 new_key = key
                 if hostvars_prefix:
                     new_key = _options["hostvars_prefix"] + new_key
                 if hostvars_suffix:
                     new_key += _options["hostvars_suffix"]
-                new_host[new_key] = host[key]
+                new_host[new_key] = value
             tmp.append(new_host)
         camel_hosts = tmp
 
