@@ -154,7 +154,7 @@ options:
     version_added: 9.4.0
 requirements:
   - When using O(name) with version specifiers, the Python package C(packaging) is required.
-  - If the package C(packaging) is at a version lesser than C(22.0.0), it will fail silently when processing invalid specifiers,
+  - If the package C(packaging) is at a version lesser than C(22.0.0), it fails silently when processing invalid specifiers,
     like C(tox<<<<4.0).
 author:
   - "Alexei Znamensky (@russoz)"
@@ -175,7 +175,7 @@ EXAMPLES = r"""
     name: tox
     state: upgrade
 
-- name: Install or upgrade tox with dependency group 'docs'
+- name: Install or upgrade tox with extra 'docs'
   community.general.pipx:
     name: tox
     source: tox[docs]
