@@ -23,29 +23,27 @@ options:
   name:
     description:
     - Name of the virtual machine to export.
-    - This is a required parameter, if parameter C(uuid) or C(moid) is not supplied.
+    - This is a required parameter, if parameter O(uuid) or O(moid) is not supplied.
     type: str
   uuid:
     description:
     - Uuid of the virtual machine to export.
-    - This is a required parameter, if parameter C(name) or C(moid) is not supplied.
+    - This is a required parameter, if parameter O(name) or O(moid) is not supplied.
     type: str
   moid:
     description:
     - Managed Object ID of the instance to manage if known, this is a unique identifier only within a single vCenter instance.
-    - This is required if C(name) or C(uuid) is not supplied.
+    - This is required if O(name) or O(uuid) is not supplied.
     type: str
   datacenter:
     default: ha-datacenter
     description:
     - Datacenter name of the virtual machine to export.
-    - This parameter is case sensitive.
     type: str
   folder:
     description:
     - Destination folder, absolute path to find the specified guest.
     - The folder should include the datacenter. ESX datacenter is ha-datacenter.
-    - This parameter is case sensitive.
     - 'If multiple machines are found with same name, this parameter is used to identify'
     - 'Examples:'
     - '   folder: /ha-datacenter/vm'
@@ -74,7 +72,6 @@ options:
     default: false
     description:
     - All extra configuration options are exported for a virtual machine.
-    version_added: '2.0.0'
   download_timeout:
     description:
     - The user defined timeout in second of exporting file.
@@ -112,7 +109,8 @@ from threading import Thread
 from ansible.module_utils.urls import open_url
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils._text import to_text, to_bytes
-from ansible_collections.community.vmware.plugins.module_utils.vmware import vmware_argument_spec, PyVmomi
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 try:
     from pyVmomi import vim
     from pyVim import connect
@@ -325,7 +323,7 @@ class VMwareExportVmOvf(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         name=dict(type='str'),
         uuid=dict(type='str'),
