@@ -40,7 +40,7 @@ options:
     description:
       - Specifies whether the monitor sends error messages and additional information to a log file created and
         labeled specifically for this monitor.
-      - "When C(yes) the system redirects error messages and additional information to the
+      - "When C(true) the system redirects error messages and additional information to the
         C(/var/log/monitors/<monitor_name>-<node_name>-<port>.log) file."
     type: bool
   domain:
@@ -92,13 +92,13 @@ options:
     description:
       - Specifies whether the system automatically changes the status of a resource
         to B(enabled) at the next successful monitor check.
-      - If you set this option to C(yes), you must manually re-enable the resource
+      - If you set this option to C(true), you must manually re-enable the resource
         before the system can use it for load balancing connections.
       - When creating a new monitor, if this parameter is not specified, the default
-        value is C(no).
-      - When C(yes), specifies you must manually re-enable the resource after an
+        value is C(false).
+      - When C(true), specifies you must manually re-enable the resource after an
         unsuccessful monitor check.
-      - When C(no), specifies the system automatically changes the status of a
+      - When C(false), specifies the system automatically changes the status of a
         resource to B(enabled) at the next successful monitor check.
     type: bool
   time_until_up:
@@ -175,7 +175,7 @@ debug:
       labeled specifically for this monitor.
   returned: changed
   type: bool
-  sample: no
+  sample: false
 domain:
   description: Specifies the domain name to check.
   returned: changed
@@ -214,7 +214,7 @@ manual_resume:
       resource to up at the next successful monitor check.
   returned: changed
   type: bool
-  sample: yes
+  sample: true
 time_until_up:
   description: The new time in which to mark a system as up after first successful response.
   returned: changed
@@ -295,16 +295,19 @@ class Parameters(AnsibleF5Parameters):
 class ApiParameters(Parameters):
     @property
     def ip(self):
-        ip, port = self._values['destination'].split(':')
+        des = self._values['destination']
+        ip, d, port = des.rpartition('.')
+        if not is_valid_ip(ip) and ip != '*':
+            ip, d, port = des.rpartition(':')
         return ip
 
     @property
     def port(self):
-        ip, port = self._values['destination'].split(':')
-        try:
-            return int(port)
-        except ValueError:
-            return port
+        des = self._values['destination']
+        ip, d, port = des.rpartition('.')
+        if not is_valid_ip(ip) and ip != '*':
+            ip, d, port = des.rpartition(':')
+        return int(port) if port.isnumeric() else port
 
     @property
     def description(self):
@@ -371,7 +374,7 @@ class ModuleParameters(Parameters):
             return None
         if self._values['ip'] in ['*', '0.0.0.0']:
             return '*'
-        elif is_valid_ip(self._values['ip']):
+        elif is_valid_ip(self._values['ip']) or is_valid_ip(self._values['ip'].split("%")[0]):
             return self._values['ip']
         else:
             raise F5ModuleError(
