@@ -123,6 +123,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -139,12 +140,12 @@ EXAMPLES = '''
         prefix_list: <your own value>
         state: present # <value in [present, absent]>
         router_prefixlist_rule:
-          action: <value in [permit, deny]>
-          flags: <integer>
-          ge: <integer>
-          id: <integer>
-          le: <integer>
-          prefix: <string>
+          id: 0 # Required variable, integer
+          # action: <value in [permit, deny]>
+          # flags: <integer>
+          # ge: <integer>
+          # le: <integer>
+          # prefix: <string>
 '''
 
 RETURN = '''
