@@ -1,4 +1,4 @@
-# (c) 2020-2023, NetApp, Inc
+# (c) 2020-2024, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit test template for ONTAP Ansible module '''
@@ -12,8 +12,9 @@ import pytest
 
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+# pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import\
-    assert_no_warnings, assert_warning_was_raised, print_warnings, call_main, create_and_apply,\
+    assert_no_warnings, assert_warning_was_raised, print_warnings, call_main, create_and_apply, \
     create_module, expect_and_capture_ansible_exception, patch_ansible
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import\
     patch_request_and_invoke, register_responses
@@ -77,7 +78,16 @@ volume_info = {
         },
         "size": 10737418240,
         "snapshot": {
-            "reserve_percent": 5
+            "reserve_percent": 5,
+            "autodelete": {
+                "enabled": False,
+                "trigger": "volume",
+                "delete_order": "oldest_first",
+                "defer_delete": "user_created",
+                "commitment": "try",
+                "target_free_space": 20,
+                "prefix": "(not specified)"
+            }
         }
     },
     "guarantee": {
@@ -88,7 +98,10 @@ volume_info = {
     },
     "analytics": {
         "state": "on"
-    }
+    },
+    "access_time_enabled": True,
+    "snapshot_directory_access_enabled": True,
+    "snapshot_locking_enabled": True
 }
 
 volume_info_mount = copy.deepcopy(volume_info)
@@ -105,12 +118,16 @@ volume_analytics_initializing = copy.deepcopy(volume_info)
 volume_analytics_initializing['analytics']['state'] = 'initializing'
 volume_info_offline = copy.deepcopy(volume_info)
 volume_info_offline['state'] = 'offline'
+volume_info_tags = copy.deepcopy(volume_info)
+volume_info_tags['_tags'] = ["team:csi", "environment:test"]
 
 # REST API canned responses when mocking send_request
 SRR = rest_responses({
     # common responses
     'is_rest': (200, dict(version=dict(generation=9, major=8, minor=0, full='dummy')), None),
     'is_rest_96': (200, dict(version=dict(generation=9, major=6, minor=0, full='dummy_9_6_0')), None),
+    'is_rest_9_8_0': (200, dict(version=dict(generation=9, major=8, minor=0, full='dummy_9_8_0')), None),
+    'is_rest_9_13_1': (200, dict(version=dict(generation=9, major=13, minor=1, full='dummy_9_13_1')), None),
     'is_zapi': (400, {}, "Unreachable"),
     'empty_good': (200, {}, None),
     'no_record': (200, {'num_records': 0, 'records': []}, None),
@@ -149,7 +166,8 @@ SRR = rest_responses({
     'analytics_off': (200, {'records': [volume_analytics_disabled]}, None),
     'analytics_initializing': (200, {'records': [volume_analytics_initializing]}, None),
     'one_svm_record': (200, {'records': [{'uuid': 'svm_uuid'}]}, None),
-    'volume_info_offline': (200, {'records': [volume_info_offline]}, None)
+    'volume_info_offline': (200, {'records': [volume_info_offline]}, None),
+    'volume_info_tags': (200, {'records': [volume_info_tags]}, None)
 })
 
 DEFAULT_APP_ARGS = {
@@ -230,7 +248,7 @@ def test_rest_error():
         ('GET', 'application/applications', SRR['no_record']),          # GET application/applications
         ('POST', 'application/applications', SRR['generic_error']),     # POST application/applications
     ])
-    error = 'Error in create_nas_application: calling: application/applications: got %s.' % SRR['generic_error'][2]
+    error = 'Error in create_application_template: calling: application/applications: got %s.' % SRR['generic_error'][2]
     assert create_and_apply(volume_module, DEFAULT_APP_ARGS, fail=True)['msg'] == error
 
 
@@ -290,6 +308,30 @@ def test_rest_successfully_resized():
     assert create_and_apply(volume_module, DEFAULT_APP_ARGS, module_args)['changed']
 
 
+def test_rest_volume_create_modify_tags():
+    ''' volume create, modify with tags
+    '''
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_13_1']),
+        ('GET', 'storage/volumes', SRR['no_record']),
+        ('GET', 'svm/svms', SRR['one_svm_record']),
+        ('POST', 'storage/volumes', SRR['success']),
+        ('GET', 'storage/volumes', SRR['volume_info_tags']),
+        # idempotent check
+        ('GET', 'cluster', SRR['is_rest_9_13_1']),
+        ('GET', 'storage/volumes', SRR['volume_info_tags']),
+        # modify tags
+        ('GET', 'cluster', SRR['is_rest_9_13_1']),
+        ('GET', 'storage/volumes', SRR['volume_info_tags']),
+        ('PATCH', 'storage/volumes/7882901a-1aef-11ec-a267-005056b30cfa', SRR['success']),
+    ])
+    module_args = {'tags': ["team:csi", "environment:test"]}
+    assert create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args)['changed']
+    assert not create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args)['changed']
+    module_args = {'tags': ["team:csi"]}
+    assert create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args)['changed']
+
+
 def test_rest_successfully_deleted():
     ''' delete volume using REST - no app
     '''
@@ -479,6 +521,142 @@ def test_rest_error_modify_attributes():
     assert create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg'] == msg
 
 
+def test_rest_version_error_with_atime_update():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_96'])
+    ])
+    module_args = {
+        'atime_update': False
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    assert 'Minimum version of ONTAP for atime_update is (9, 8)' in error
+
+
+def test_rest_version_error_with_snapdir_access():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_12_1'])
+    ])
+    module_args = {
+        'snapdir_access': False
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    assert 'Minimum version of ONTAP for snapdir_access is (9, 13, 1)' in error
+
+
+def test_rest_version_error_with_snapshot_auto_delete():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_12_1'])
+    ])
+    module_args = {
+        'snapshot_auto_delete': {'state': 'on'}
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    assert 'Minimum version of ONTAP for snapshot_auto_delete is (9, 13, 1)' in error
+
+
+def test_rest_version_error_with_vol_nearly_full_threshold_percent():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0'])
+    ])
+    module_args = {
+        'vol_nearly_full_threshold_percent': 96
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    assert 'Minimum version of ONTAP for vol_nearly_full_threshold_percent is (9, 9)' in error
+
+
+def test_rest_version_error_with_large_size_enabled():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest'])
+    ])
+    module_args = {
+        'large_size_enabled': False
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    assert 'Minimum version of ONTAP for large_size_enabled is (9, 12, 1)' in error
+
+
+def test_rest_version_error_with_snapshot_locking():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0'])
+    ])
+    module_args = {
+        'snapshot_locking': False
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    print('error', error)
+    assert 'Minimum version of ONTAP for snapshot_locking is (9, 12, 1)' in error
+
+
+def test_rest_version_error_with_activity_tracking():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0'])
+    ])
+    module_args = {
+        'activity_tracking': 'on'
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    assert 'Minimum version of ONTAP for activity_tracking is (9, 10, 1)' in error
+
+
+def test_rest_successfully_modify_attributes_atime_update():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0']),
+        ('GET', 'storage/volumes', SRR['get_volume']),                                          # Get Volume
+        ('PATCH', 'storage/volumes/7882901a-1aef-11ec-a267-005056b30cfa', SRR['no_record']),    # Modify
+    ])
+    module_args = {
+        'atime_update': False,
+    }
+    assert create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args)['changed']
+
+
+def test_rest_successfully_modify_attributes_snapdir_access_and_snapshot_auto_delete():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_13_1']),
+        ('GET', 'storage/volumes', SRR['get_volume']),                                          # Get Volume
+        ('PATCH', 'storage/volumes/7882901a-1aef-11ec-a267-005056b30cfa', SRR['no_record']),    # Modify
+    ])
+    module_args = {
+        'snapdir_access': False,
+        'snapshot_auto_delete': {
+            'state': 'on',
+            'trigger': 'volume',
+            'delete_order': 'oldest_first',
+            'defer_delete': 'user_created',
+            'commitment': 'try',
+            'target_free_space': 25,
+            'prefix': 'prefix1'
+        }
+    }
+    assert create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args)['changed']
+
+
+def test_rest_successfully_modify_vol_threshold_percent_params():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_9_0']),
+        ('GET', 'storage/volumes', SRR['get_volume']),                                          # Get Volume
+        ('PATCH', 'storage/volumes/7882901a-1aef-11ec-a267-005056b30cfa', SRR['no_record']),    # Modify
+    ])
+    module_args = {
+        'vol_nearly_full_threshold_percent': 98,
+        'vol_full_threshold_percent': 99
+    }
+    assert create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args)['changed']
+
+
+def test_rest_successfully_modify_large_size_enabled():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_12_1']),
+        ('GET', 'storage/volumes', SRR['get_volume']),                                          # Get Volume
+        ('PATCH', 'storage/volumes/7882901a-1aef-11ec-a267-005056b30cfa', SRR['no_record']),    # Modify
+    ])
+    module_args = {
+        'large_size_enabled': False
+    }
+    assert create_and_apply(volume_module, DEFAULT_VOLUME_ARGS, module_args)['changed']
+
+
 def test_rest_successfully_create_volume():
     register_responses([
         ('GET', 'cluster', SRR['is_rest']),
@@ -1168,6 +1346,29 @@ def test_create_nas_app_tiering_flexcache():
     assert create_and_apply(volume_module, DEFAULT_APP_ARGS, module_args)['changed']
 
 
+def test_create_nas_app_cifs_options():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_12_1']),
+        ('GET', 'storage/volumes', SRR['no_record']),               # Get Volume
+        ('GET', 'svm/svms', SRR['one_svm_record']),
+        ('GET', 'application/applications', SRR['no_record']),      # GET application/applications
+        ('POST', 'application/applications', SRR['empty_good']),    # POST application/applications
+        ('GET', 'storage/volumes', SRR['get_volume']),
+    ])
+    module_args = {
+        'nas_application_template': {
+            'cifs_access': [
+                {
+                    'access': 'read'
+                }
+            ],
+            'cifs_share_name': 'test_share',
+            'exclude_aggregates': ['aggr_ex'],
+        }
+    }
+    assert create_and_apply(volume_module, DEFAULT_APP_ARGS, module_args)['changed']
+
+
 def test_version_error_nas_app():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_96']),
@@ -1202,6 +1403,20 @@ def test_version_error_nas_app_dr_cache():
     assert create_module(volume_module, DEFAULT_APP_ARGS, module_args, fail=True)['msg'] == error
 
 
+def test_version_error_nas_app_cifs_share_name():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_97']),
+    ])
+    module_args = {
+        'nas_application_template': {
+            'cifs_share_name': 'test_share2',
+            'cifs_access': [{'access': 'read'}]
+        }
+    }
+    error = 'Error: using nas_application_template: cifs_share_name requires ONTAP 9.11 or later and REST must be enabled - ONTAP version: 9.7.0.'
+    assert create_module(volume_module, DEFAULT_APP_ARGS, module_args, fail=True)['msg'] == error
+
+
 def test_error_volume_rest_patch():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_9_10_1']),
@@ -1232,8 +1447,8 @@ def test_error_modify_app_not_supported_no_volume_but_app():
     ])
     module_args = {}
     # TODO: we need to handle this error case with a better error mssage
-    error = \
-        'Error in create_nas_application: function create_application should not be called when application uuid is set: 09e9fd5e-8ebd-11e9-b162-005056b39fe7.'
+    error = 'Error in create_application_template: function create_application should not be called when application uuid is set: '
+    error += '09e9fd5e-8ebd-11e9-b162-005056b39fe7.'
     assert create_and_apply(volume_module, DEFAULT_APP_ARGS, module_args, fail=True)['msg'] == error
 
 
