@@ -8,12 +8,6 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-ANSIBLE_METADATA = {
-    "metadata_version": "1.1",
-    "status": ["preview"],
-    "supported_by": "community",
-}
-
 DOCUMENTATION = r"""
 ---
 module: netbox_prefix
@@ -61,9 +55,28 @@ options:
         type: int
       site:
         description:
-          - Site that prefix is associated with
+          - Site that prefix is associated with (Deprecated in NetBox 4.2+)
+          - Will be removed in version 5.0.0
         required: false
         type: raw
+      scope_type:
+        description:
+          - Type of scope to be applied (NetBox 4.2+)
+        required: false
+        type: str
+        choices:
+          - "dcim.location"
+          - "dcim.rack"
+          - "dcim.region"
+          - "dcim.site"
+          - "dcim.sitegroup"
+        version_added: "3.21.0"
+      scope:
+        description:
+          - Object related to scope type (NetBox 4.2+)
+        required: false
+        type: raw
+        version_added: "3.21.0"
       vrf:
         description:
           - VRF that prefix is associated with
@@ -94,11 +107,23 @@ options:
           - All IP Addresses within this prefix are considered usable
         required: false
         type: bool
+      mark_utilized:
+        description:
+          - Treat as 100% utilized
+        required: false
+        type: bool
+        version_added: "3.8.0"
       description:
         description:
           - The description of the prefix
         required: false
         type: str
+      comments:
+        description:
+          - Comments that may include additional information in regards to the prefix
+        required: false
+        type: str
+        version_added: "3.10.0"
       tags:
         description:
           - Any tags that the prefix may need to be associated with
@@ -125,11 +150,11 @@ EXAMPLES = r"""
 - name: "Test NetBox prefix module"
   connection: local
   hosts: localhost
-  gather_facts: False
+  gather_facts: false
 
   tasks:
     - name: Create prefix within NetBox with only required information
-      netbox_prefix:
+      netbox.netbox.netbox_prefix:
         netbox_url: http://netbox.local
         netbox_token: thisIsMyToken
         data:
@@ -137,7 +162,7 @@ EXAMPLES = r"""
         state: present
 
     - name: Delete prefix within netbox
-      netbox_prefix:
+      netbox.netbox.netbox_prefix:
         netbox_url: http://netbox.local
         netbox_token: thisIsMyToken
         data:
@@ -145,7 +170,7 @@ EXAMPLES = r"""
         state: absent
 
     - name: Create prefix with several specified options
-      netbox_prefix:
+      netbox.netbox.netbox_prefix:
         netbox_url: http://netbox.local
         netbox_token: thisIsMyToken
         data:
@@ -168,17 +193,17 @@ EXAMPLES = r"""
         state: present
 
     - name: Get a new /24 inside 10.156.0.0/19 within NetBox - Parent doesn't exist
-      netbox_prefix:
+      netbox.netbox.netbox_prefix:
         netbox_url: http://netbox.local
         netbox_token: thisIsMyToken
         data:
           parent: 10.156.0.0/19
           prefix_length: 24
         state: present
-        first_available: yes
+        first_available: true
 
     - name: Create prefix within NetBox with only required information
-      netbox_prefix:
+      netbox.netbox.netbox_prefix:
         netbox_url: http://netbox.local
         netbox_token: thisIsMyToken
         data:
@@ -186,17 +211,17 @@ EXAMPLES = r"""
         state: present
 
     - name: Get a new /24 inside 10.156.0.0/19 within NetBox
-      netbox_prefix:
+      netbox.netbox.netbox_prefix:
         netbox_url: http://netbox.local
         netbox_token: thisIsMyToken
         data:
           parent: 10.156.0.0/19
           prefix_length: 24
         state: present
-        first_available: yes
+        first_available: true
 
     - name: Get a new /24 inside 10.157.0.0/19 within NetBox with additional values
-      netbox_prefix:
+      netbox.netbox.netbox_prefix:
         netbox_url: http://netbox.local
         netbox_token: thisIsMyToken
         data:
@@ -205,7 +230,21 @@ EXAMPLES = r"""
           vrf: Test VRF
           site: Test Site
         state: present
-        first_available: yes
+        first_available: true
+
+    - name: Create prefix with scope (NetBox 4.2+)
+      netbox.netbox.netbox_prefix:
+        netbox_url: http://netbox.local
+        netbox_token: thisIsMyToken
+        data:
+          prefix: 10.156.32.0/19
+          scope_type: "dcim.site"
+          scope: Test Site
+          vrf: Test VRF
+          tenant: Test Tenant
+          status: Reserved
+          description: Test description
+        state: present
 """
 
 RETURN = r"""
@@ -246,14 +285,33 @@ def main():
                     prefix=dict(required=False, type="raw"),
                     parent=dict(required=False, type="raw"),
                     prefix_length=dict(required=False, type="int"),
-                    site=dict(required=False, type="raw"),
+                    site=dict(
+                        required=False,
+                        type="raw",
+                        removed_in_version="5.0.0",
+                        removed_from_collection="netbox.netbox",
+                    ),
+                    scope_type=dict(
+                        required=False,
+                        type="str",
+                        choices=[
+                            "dcim.location",
+                            "dcim.rack",
+                            "dcim.region",
+                            "dcim.site",
+                            "dcim.sitegroup",
+                        ],
+                    ),
+                    scope=dict(required=False, type="raw"),
                     vrf=dict(required=False, type="raw"),
                     tenant=dict(required=False, type="raw"),
                     vlan=dict(required=False, type="raw"),
                     status=dict(required=False, type="raw"),
                     prefix_role=dict(required=False, type="raw"),
                     is_pool=dict(required=False, type="bool"),
+                    mark_utilized=dict(required=False, type="bool"),
                     description=dict(required=False, type="str"),
+                    comments=dict(required=False, type="str"),
                     tags=dict(required=False, type="list", elements="raw"),
                     custom_fields=dict(required=False, type="dict"),
                 ),
