@@ -27,7 +27,7 @@ DOCUMENTATION = '''
 module: ovirt_storage_vm_info
 short_description: Retrieve information about one or more oVirt/RHV virtual machines relate to a storage domain.
 version_added: "1.0.0"
-author: "Maor Lipchuk (@machacekondra)"
+author: "oVirt Developers (@oVirt)"
 description:
     - "Retrieve information about one or more oVirt/RHV virtual machines relate to a storage domain."
     - This module was called C(ovirt_storage_vm_facts) before Ansible 2.9, returning C(ansible_facts).
@@ -51,6 +51,17 @@ options:
         description:
             - "The storage domain name where the virtual machines should be listed."
         type: str
+        required: True
+    follow:
+        description:
+            - List of linked entities, which should be fetched along with the main entity.
+            - This parameter replaces usage of C(fetch_nested) and C(nested_attributes).
+            - "All follow parameters can be found at following url: https://ovirt.github.io/ovirt-engine-api-model/master/#types/vm/links_summary"
+        type: list
+        version_added: 1.5.0
+        elements: str
+        aliases: ['follows']
+        default: []
 extends_documentation_fragment: ovirt.ovirt.ovirt_info
 '''
 
@@ -61,7 +72,8 @@ EXAMPLES = '''
 # Gather information about all VMs which relate to a storage domain and
 # are unregistered:
 - ovirt.ovirt.ovirt_storage_vm_info:
-    unregistered=True
+    unregistered: true
+    storage_domain: storage
   register: result
 - ansible.builtin.debug:
     msg: "{{ result.ovirt_storage_vms }}"
@@ -89,16 +101,19 @@ from ansible_collections.ovirt.ovirt.plugins.module_utils.ovirt import (
 
 def main():
     argument_spec = ovirt_info_full_argument_spec(
-        storage_domain=dict(default=None),
+        storage_domain=dict(type='str', required=True),
         max=dict(default=None, type='int'),
         unregistered=dict(default=False, type='bool'),
     )
-    module = AnsibleModule(argument_spec)
+    module = AnsibleModule(
+        argument_spec,
+        supports_check_mode=True,
+    )
     check_sdk(module)
     if module.params['fetch_nested'] or module.params['nested_attributes']:
         module.deprecate(
             "The 'fetch_nested' and 'nested_attributes' are deprecated please use 'follow' parameter",
-            version='3.0.0',
+            version='4.0.0',
             collection_name='ovirt.ovirt'
         )
 
